@@ -25,7 +25,6 @@
 #endif
 
 #include <string>
-#include <cstdlib>
 
 #include <gtkmm/eventcontrollerlegacy.h>
 
@@ -485,15 +484,16 @@ AppWindow::handle_login()
             Lifeograph::icons->todo_canceled_32 =   Gdk::Pixbuf::create_from_file(
                     Lifeograph::get_icon_dir() + "/todo_canceled-32.png" );
 
-            Lifeograph::icons->filter = lookup_default_icon_pixbuf( "filter-16-symbolic", 16 );
-            Lifeograph::icons->table = lookup_default_icon_pixbuf( "table-16-symbolic", 16 );
-            Lifeograph::icons->chart = lookup_default_icon_pixbuf( "chart-16-symbolic", 16 );
+            Lifeograph::icons->filter = lookup_theme_icon_pixbuf( theme, "filter-16-symbolic", 16 );
+            Lifeograph::icons->table = lookup_theme_icon_pixbuf( theme, "table-16-symbolic", 16 );
+            Lifeograph::icons->chart = lookup_theme_icon_pixbuf( theme, "chart-16-symbolic", 16 );
 
-            Lifeograph::icons->map_point = lookup_default_icon_pixbuf( "map-point", 16 );
+            Lifeograph::icons->map_point = lookup_theme_icon_pixbuf( theme, "map-point", 16 );
 
-            Lifeograph::icons->go_prev = lookup_default_icon_pixbuf( "go-previous-symbolic", 16 );
-            Lifeograph::icons->go_next = lookup_default_icon_pixbuf( "go-next-symbolic", 16 );
-            Lifeograph::icons->go_home = lookup_default_icon_pixbuf( "go-home-symbolic", 16 );
+            Lifeograph::icons->go_prev = lookup_theme_icon_pixbuf( theme, "go-previous-symbolic",
+                                                                   16 );
+            Lifeograph::icons->go_next = lookup_theme_icon_pixbuf( theme, "go-next-symbolic", 16 );
+            Lifeograph::icons->go_home = lookup_theme_icon_pixbuf( theme, "go-home-symbolic", 16 );
 
             // PANELS & VIEWS
             UI_diary = new UIDiary;
