@@ -620,7 +620,7 @@ class Diary : public DiaryElement
         mutable std::mutex      m_mutex_postread_operations;
         std::thread*            m_thread_postread_operations{ nullptr };
 
-        void                    create_db_entry_text( const Entry* ); // helper
+        void                    create_db_entry_text( const Entry*, FiltererContainer* ); // helper
         void                    create_db_header_text( bool );
         bool                    create_db_body_text();
 
@@ -632,6 +632,8 @@ class Diary : public DiaryElement
     private:
         size_t                  m_size_bytes      { 0 };
         StrStream*              m_sstream         { nullptr };
+        // last top level entry to add siblings to when saving filetered entries only
+        const Entry*            m_p2top_entry_last;
 
         int                     m_login_status    { LOGGED_OUT };
 
