@@ -397,7 +397,7 @@ Theme::calculate_derived_colors()
     color_link =          contrast2( color_base, s_color_link1, s_color_link2 );
     color_link_broken =   contrast2( color_base, s_color_broken1, s_color_broken2 );
 
-    // TODO: we may change the coefficients below depending on the difference between the...
+    // TODO: 3.2: we may change the coefficients below depending on the difference between the...
     // ... contrasting colors using get_color_diff( Theme::s_color_done, theme->color_base )...
     // ... generally, when get_color_diff is < 1.0 contrast is not satisfactory
     color_open =          midtone( s_color_todo, color_text );
@@ -424,23 +424,27 @@ Theme::get_css_class_def() const
                                            : STR::compose( "url(\"", image_bg, "\")" ) };
 
     return( STR::compose(
-            "textview.", name, " { "
+            "textview#", name, " { "
                 "color: ",              c_text, "; "
                 "font-family: ",        font_f, "; "
                 "font-size: ",          size,   "pt; "
                 "caret-color: ",        c_text, "; }\n"
-            "textview.", name, " text selection { "
+            "textview#", name, " text selection { "
                 "color: ",              c_base, "; "
                 "background: ",   color_heading.to_string(), "; }\n"
-            "textview.", name, " text:selected { "
+            "textview#", name, " text:selected { "
                 "color: ",              c_base, "; "
                 "background: ",   color_heading.to_string(), "; }\n"
-            "textview.", name, " text { "
+            "textview#", name, " text { "
                 "background-color: ",   c_base, "; "
                 "background-image: ",   bg_img, "; }\n"
             "button.", name, " { "
                 "background-color: ",   c_base, "; "
-                "background-image: ",   bg_img, "; }" ) );
+                "background-image: ",   bg_img, "; }\n"
+            "entry#noncustom text { background-color: initial; background-image: initial; }\n"
+            "combobox#noncustom entry text { background-color: initial; "
+                                            "background-image: initial; }" ) );
+    // noncustom specialization is to revert children of the main textview to defaults
 }
 
 // THEMESYSTEM =====================================================================================
@@ -606,7 +610,7 @@ ChartData::set_from_string( const Ustring& chart_def )
 void
 ChartData::set_from_string_old( const Ustring& chart_def )
 {
-    // TODO: to be improved but it may not worth to effort to implement upgrading all sorts of...
+    // TODO: 3.1: to be improved but it may not worth to effort to implement upgrading all sorts of...
     //       ...older charts
     String      line;
     StringSize  line_offset{ 0 };
@@ -660,7 +664,7 @@ ChartData::set_from_string_old( const Ustring& chart_def )
                 switch( line[ 3 ] )
                 {
                     case 'Y': m_tcidu = COLUMN_PREV_YEAR; break;
-                    case 'P':  break; // planned - TODO: 3.0
+                    case 'P':  break; // planned - TODO: 3.1
                 }
                 switch( line[ 4 ] )
                 {
@@ -833,7 +837,7 @@ ChartData::fill_in_date_underlays()
     {
         case ChartData::PERIOD_DAILY:
             //offset = Date::get_days_in_year( Date::get_year( d ) - 1 );
-            offset = 365; // TODO: incorporate leap years
+            offset = 365; // TODO: 3.1: incorporate leap years
             break;
         case ChartData::PERIOD_WEEKLY: offset = 52; break;
         // case ChartData::PERIOD_MONTHLY:
@@ -965,7 +969,7 @@ ChartData::calculate_points()
             case ChartData::TYPE_DATE:
                 if( col->get_type() == TableColumn::TCT_GANTT )
                 {
-                    // TODO: subdivide the value when necessary
+                    // TODO: 3.1: subdivide the value when necessary
                     // if( m_tcidy != ChartData::COLUMN_COUNT )
                     // {
                     //     const Value vy_sub{ vy / period };
