@@ -190,7 +190,7 @@ Entry::get_parent_unfiltered( FiltererContainer* fc ) const
 {
     for( Entry* ep = m_p2parent; ep; ep = ep->m_p2parent )
     {
-        if( !fc->filter( ep ) )
+        if( fc->filter( ep ) )
             return ep;
     }
     return nullptr;
@@ -200,7 +200,7 @@ Entry::get_prev_unfiltered( FiltererContainer* fc ) const
 {
     for( Entry* ep = m_p2prev; ep; ep = ep->m_p2prev )
     {
-        if( !fc->filter( ep ) )
+        if( fc->filter( ep ) )
             return ep;
     }
     return nullptr;
@@ -331,6 +331,7 @@ Entry::add_sibling_before( Entry* e )
 
     e->m_p2parent = m_p2parent;
     e->m_p2next = this;
+    e->m_sibling_order = m_sibling_order;
     m_p2prev = e;
 
     if( m_p2diary && m_p2diary->get_entry_1st() == this )
@@ -1639,7 +1640,8 @@ Entry::update_inline_dates()
     if( m_date_finish == Date::NOT_SET )
         m_date_finish = m_date;
 
-    if( Date::isolate_YMD( m_date ) != date_prev && m_p2diary )
+    // DEID_OMIT is used for temoorary entries that are not part of the diary
+    if( m_id != DEID_OMIT && Date::isolate_YMD( m_date ) != date_prev && m_p2diary )
         m_p2diary->set_entry_date( this, m_date );
 }
 
