@@ -100,10 +100,15 @@ class Entry : public DiaryElemDataSrc
         Entry*                  get_parent_unfiltered( FiltererContainer* fc ) const;
         Entry*                  get_child_1st() const { return m_p2child_1st; }
         Entry*                  get_prev() const      { return m_p2prev; }
+        Entry*                  get_prev_cyclic()
+        { return( m_p2prev ? m_p2prev : ( m_p2next ? get_sibling_last() : nullptr ) ); }
         Entry*                  get_prev_or_up() const
         { return( m_p2prev ? m_p2prev : m_p2parent ); }
         Entry*                  get_next() const      { return m_p2next; }
+        Entry*                  get_next_cyclic()
+        { return( m_p2next ? m_p2next : ( m_p2prev ? get_sibling_1st() : nullptr ) ); }
         Entry*                  get_prev_unfiltered( FiltererContainer* fc ) const;
+        Entry*                  get_prev_straight( bool = true ) const;
         Entry*                  get_next_straight( bool = true ) const;
         Entry*                  get_next_straight( const Entry*, bool = true ) const;
         Entry*                  get_sibling_1st();
@@ -172,10 +177,12 @@ class Entry : public DiaryElemDataSrc
         }
         void                    set_filtered_out( bool filteredout )
         {
+            // for the following to work always call this function in a parent-to-child order:
+            m_status &= ~ES::HAS_VSBL_DESCENDANT;
+
             if( filteredout )
             {
                 m_status |= ES::FILTERED_OUT;
-                m_status &= ~ES::HAS_VSBL_DESCENDANT;
             }
             else
             {
@@ -295,10 +302,6 @@ class Entry : public DiaryElemDataSrc
             }
             return number;
         }
-        int                     get_list_order() const
-        { return m_list_order; }
-        void                    set_list_order( int order )
-        { m_list_order = order; }
         void                    update_sibling_orders();
         int                     get_sibling_order() const
         { return m_sibling_order; }
@@ -500,7 +503,6 @@ class Entry : public DiaryElemDataSrc
 
         DateV                   m_date_created;
         DateV                   m_date_edited;
-        int                     m_list_order    { 0 };  // starts from 0
         int                     m_sibling_order { 1 };  // starts from 1
         Paragraph*              m_p2para_1st    { nullptr };
         Paragraph*              m_p2para_last   { nullptr };
@@ -526,7 +528,7 @@ class Entry : public DiaryElemDataSrc
 
         UndoStack               m_session_edits;
 
-    friend class Diary; // TODO: remove this friendship too??
+    friend class Diary;
 };
 
 // MAIN ENTRY POOL =================================================================================
