@@ -693,7 +693,7 @@ class Filter : public StringDefElem
         int                     m_num_users{ 0 };
 };
 
-typedef std::map< Ustring, Filter*, FuncCmpStrings > MapUstringFilter;
+using MapUstringFilter = MapUstringDiaryElem< Filter >;
 
 } // end of namespace LIFEO
 
