@@ -72,9 +72,12 @@ Paragraph::get_prev_sibling() const
 {
     for( auto prev = m_p2prev; prev; prev = prev->m_p2prev )
     {
-        if( prev->get_indent_level() < get_indent_level() )
+        if( prev->get_indent_level() < get_indent_level() ||
+            prev->get_heading_level() < get_heading_level() ||
+            prev->is_empty_completely() )
             break;
-        if( prev->get_indent_level() == get_indent_level() )
+        if( prev->get_indent_level() == get_indent_level() &&
+            prev->get_heading_level() == get_heading_level() )
             return prev;
     }
 
@@ -85,15 +88,30 @@ Paragraph::get_next_sibling() const
 {
     for( auto next = m_p2next; next; next = next->m_p2next )
     {
-        if( next->get_indent_level() < get_indent_level() )
+        if( next->get_indent_level() < get_indent_level() ||
+            next->get_heading_level() < get_heading_level() ||
+            next->is_empty_completely() )
             break;
-        if( next->get_indent_level() == get_indent_level() )
+        if( next->get_indent_level() == get_indent_level() &&
+            next->get_heading_level() == get_heading_level() )
             return next;
     }
 
     return nullptr;
 }
 
+ListParagraphs
+Paragraph::get_siblings() const
+{
+    ListParagraphs siblings{ const_cast< Paragraph* >( this ) };
+    for( auto prev = get_prev_sibling(); prev; prev = prev->get_prev_sibling() )
+        siblings.push_front( prev );
+    for( auto next = get_next_sibling(); next; next = next->get_next_sibling() )
+        siblings.push_back( next );
+
+    return siblings;
+}
+
 Paragraph*
 Paragraph::get_nth_next( int n )
 {
@@ -127,7 +145,7 @@ Paragraph::get_parent() const
             if( prev->is_header() ) // entry title is not a parent
                 break;
 
-            if( prev->is_sub( this ) )
+            if( prev->is_parent_of( this ) )
                 return prev;
         }
     }
@@ -158,7 +176,7 @@ Paragraph::get_sub_last() const
 
     for( Paragraph* p = m_p2next; p; p = p->m_p2next )
     {
-        if( is_sub( p ) )
+        if( this->is_parent_of( p ) )
             p_sub = p;
         else
             break;
@@ -175,7 +193,7 @@ Paragraph::get_sub_last_visible( bool F_force_1st_gen ) const
 
     for( Paragraph* p = m_p2next; p; p = p->m_p2next )
     {
-        if( is_sub( p ) )
+        if( this->is_parent_of( p ) )
         {
             if( p->is_visible() && ( !F_force_1st_gen || p->get_parent() == this ) )
                 p_sub = p;
@@ -188,6 +206,27 @@ Paragraph::get_sub_last_visible( bool F_force_1st_gen ) const
 
     return p_sub;
 }
+Paragraph*
+Paragraph::get_sub_last_invisible() const
+// Caution: returns itself in the absence of any visible sub
+{
+    Paragraph* p_sub{ const_cast< Paragraph* >( this ) };
+
+    for( Paragraph* p = m_p2next; p; p = p->m_p2next )
+    {
+        if( is_parent_of( p ) )
+        {
+            if( !p->is_visible() )
+                p_sub = p;
+            else
+                continue;
+        }
+        else
+            break;
+    }
+
+    return p_sub;
+}
 
 bool
 Paragraph::is_last_in_host() const
@@ -277,7 +316,7 @@ Ustring
 Paragraph::get_name() const
 {
     //return STR::compose( m_host->get_name(), ":", m_order_in_host );
-    return get_text(); // TODO: find a better way of describing a paragraph
+    return get_text(); // TODO: 3.2: find a better way of describing a paragraph
 }
 
 int
@@ -505,7 +544,10 @@ Paragraph::inherit_style_from( const Paragraph* para, bool F_heading_level_too )
     set_indent_level( para->get_indent_level() );
 
     if( F_heading_level_too )
+    {
+        set_hrule( para->is_hrule() );
         set_heading_level( para->get_heading_level() );
+    }
 }
 
 void
@@ -515,7 +557,7 @@ Paragraph::set_expanded( bool F_expanded )
 
     for( Paragraph* p = m_p2next; p; p = p->m_p2next )
     {
-        if( is_sub( p ) )
+        if( is_parent_of( p ) )
             p->reset_visibility();
         else
             break;
@@ -689,7 +731,7 @@ Paragraph::get_sub_tag_lowest( const Entry* parent ) const
             {
                 if( sub_tag_lowest )
                 {
-                    if( sub_tag->get_list_order() < sub_tag_lowest->get_list_order() )
+                    if( sub_tag->get_sibling_order() < sub_tag_lowest->get_sibling_order() )
                         sub_tag_lowest = sub_tag;
                 }
                 else
@@ -714,7 +756,7 @@ Paragraph::get_sub_tag_highest( const Entry* parent ) const
             {
                 if( sub_tag_highest )
                 {
-                    if( sub_tag->get_list_order() > sub_tag_highest->get_list_order() )
+                    if( sub_tag->get_sibling_order() > sub_tag_highest->get_sibling_order() )
                         sub_tag_highest = sub_tag;
                 }
                 else
@@ -868,19 +910,6 @@ Paragraph::set_para_type2( int type )
     }
 }
 
-void
-Paragraph::change_ordered_list_type()
-{
-    const int lt{ get_list_type() };
-    if( !( lt & VT::PS_ORDERED_GEN ) || lt == VT::PS_SROMAN )
-        set_list_type( VT::PS_NUMBER );
-    else
-        set_list_type( lt + 0x10 );
-
-    if( get_indent_level() == 0 )
-        set_indent_level( 1 );
-}
-
 bool
 Paragraph::set_indent_level( int lvl )
 {
@@ -907,17 +936,25 @@ update_para_style_after_after_indentation_change( Paragraph* p )
             p->set_list_type( ns->get_list_type() );
     }
 }
-void
+bool
 Paragraph::indent()
 {
     if( set_indent_level( get_indent_level() + 1 ) )
+    {
         update_para_style_after_after_indentation_change( this );
+        return true;
+    }
+    return false;
 }
-void
+bool
 Paragraph::unindent()
 {
     if( set_indent_level( get_indent_level() - 1 ) )
+    {
         update_para_style_after_after_indentation_change( this );
+        return true;
+    }
+    return false;
 }
 
 void
@@ -1214,7 +1251,7 @@ Paragraph::get_format_at( int type, UstringSize pos_bgn, UstringSize pos_end ) c
 {
     for( auto& format : m_formats )
     {
-        if( format->type == type && format->pos_bgn < pos_end && format->pos_end > pos_bgn )
+        if( format->type == type && format->pos_bgn < pos_end && format->pos_end >= pos_bgn )
             return format;
     }
     return nullptr;
@@ -1295,16 +1332,16 @@ Paragraph::predict_indent_from_text()
     // match the indent level from previous paras of the same type:
     for( Paragraph* p = m_p2prev; p && p->m_order_in_host < m_order_in_host; p = p->m_p2prev )
     {
-        const auto pt{ p->get_para_type() };
-
-        if( pt == get_para_type() )
+        if( p->get_para_type() == get_para_type() )
         {
             indent_level = p->get_indent_level();
             break;
         }
-        // else   // TODO: it is unclear what this was for
-        // if( p->is_list() && p->get_indent_level() >= indent_level )
-        //     indent_level = ( p->get_indent_level() + 1 );
+        // indent if different than the previous list paragraph
+        // TODO: 3.1: we may as well need to outdent based on the parents of p
+        else
+        if( p->is_list() && p->get_indent_level() >= indent_level )
+            indent_level = ( p->get_indent_level() + 1 );
     }
 
     // it is not beautiful the lists to hace 0 indent (questionable):
