@@ -46,6 +46,8 @@ TableColumn::set_type( Type type )
         else
             m_p2data->m_p2col_gantt = this;
     }
+    else if( m_p2data->m_p2col_gantt == this )
+        m_p2data->m_p2col_gantt = nullptr;
 
     m_type = type;
     m_summary_func = ( is_numeric() ? VT::SUMF::SUM::C : VT::SUMF::NONE::C );
@@ -849,7 +851,7 @@ TableColumn::calculate_arithmetic( TableLine* line ) const
         }
     }
 
-    // TODO: handle dates differently
+    // TODO: 3.1: handle dates differently
     switch( m_opt_int & VT::TCAo::FILTER )
     {
         default:               return( vA + vB );
@@ -1243,13 +1245,13 @@ TableLine::subtract_line_from_total( TableLine* line )
         else
             continue;
 
-        // TODO: the ones below require recalculation:
+        // TODO: 3.1: the ones below require recalculation:
         // case TableColumn::TCT_TODO_STATUS:
         // case TableColumn::TCT_GANTT:
         // case TableColumn::TCT_BOOL:
         // case TableColumn::TCT_SUB:
 
-        // TODO: min and max values needs recalculation
+        // TODO: 3.1: min and max values needs recalculation
 
         col->format_number( this ); // use set_total_value_strings?
     }
@@ -1720,38 +1722,10 @@ TableData::set_from_string( const Ustring& def )
                                 col->set_count_filter( m_p2diary->get_filter(
                                         std::stoul( line.substr( 4 ) ) ) );
                                 break;
-                              // TODO: below are needed to support db v2000:
-//                            case 'l':
-//                                switch( line[ 4 ] )
-//                                {
-//                                    case '<':
-//                                        col->set_condition_rel_lo( TableColumn::C_LESS );
-//                                        break;
-//                                    case '[':
-//                                        col->set_condition_rel_lo( TableColumn::C_LESS_OR_EQUAL );
-//                                        break;
-//                                }
-//                                if( line[ 4 ] != '_' )
-//                                    col->set_condition_num_lo( STR::get_d( line.substr( 5 ) ) );
-//                                break;
-//                            case 'h':
-//                                switch( line[ 4 ] )
-//                                {
-//                                    case '<':
-//                                        col->set_condition_rel_hi( TableColumn::C_LESS );
-//                                        break;
-//                                    case '[':
-//                                        col->set_condition_rel_hi( TableColumn::C_LESS_OR_EQUAL );
-//                                        break;
-//                                    case '=':
-//                                        col->set_condition_rel_hi( TableColumn::C_EQUAL );
-//                                        break;
-//                                    default:
-//                                        col->set_condition_rel_hi( TableColumn::C_IGNORE );
-//                                }
-//                                if( line[ 4 ] != '_' )
-//                                    col->set_condition_num_hi( STR::get_d( line.substr( 5 ) ) );
-//                                break;
+                           // NOTE: numeric limits were removed in favor of filters...
+                           // ... these have to be set manually after update:
+                           // case 'l':
+                           // case 'h':
                         }
                         break;
                 }
@@ -1763,10 +1737,9 @@ TableData::set_from_string( const Ustring& def )
             case 'l':   // filter
                 m_filter_para = m_p2diary->get_filter( std::stoul( line.substr( 2 ) ) );
                 break;
-                // TODO: below are needed to support db v2000:
-//            case 't':
-//                m_tag_filter = m_p2diary->get_entry_by_id( std::stoul( line.substr( 2 ) ) );
-//                break;
+            // NOTE: tag filters were removed in favor of generic filters...
+            // ... these have to be set manually after update:
+            // case 't':
             case 'o':
                 if( line[ 2 ] == 'G' || line[ 2 ] == '_' ) // to support pre v2016
                     m_grouping_depth = 0;
