@@ -437,7 +437,7 @@ class TableData
         void                        resort_lines();
         void                        sort_group_lines( TableLine* );
 
-        // TODO: move the below methods to TableLine at he earliest conveninece:
+        // TODO: 3.1: consider moving the below methods to TableLine:
         double                      get_value( unsigned int, unsigned int ) const;
         double                      get_value_pure( unsigned int, unsigned int ) const;
         double                      get_weight( unsigned int, unsigned int ) const;
@@ -547,6 +547,8 @@ class TableData
 class TableElem : public StringDefElem
 {
     public:
+        using GValue = Glib::Value< TableElem* >;
+
         static const Ustring DEFINITION_DEFAULT;
         static const Ustring DEFINITION_REPORT;
 
@@ -559,7 +561,7 @@ class TableElem : public StringDefElem
         const R2Pixbuf&         get_icon() const override;
 };
 
-typedef std::map< Ustring, TableElem*, FuncCmpStrings > MapUstringTableElem;
+using MapUstringTableElem = MapUstringDiaryElem< TableElem >;
 
 } // end of namespace LIFEO
 
