@@ -2032,13 +2032,23 @@ select_LB_item_next( Gtk::ListBox* LB )
 }
 
 R2Pixbuf
-lookup_default_icon_pixbuf( const Ustring& name, int size )
+lookup_theme_icon_pixbuf( const Glib::RefPtr< Gtk::IconTheme >& theme, const Ustring& name,
+                          int size )
 {
-    auto icon { Gtk::IconTheme::get_for_display( Gdk::Display::get_default() )->
-                        lookup_icon( name, size ) };
-    auto path { icon->get_file()->get_path() };
+    auto icon { theme->lookup_icon( name, size ) };
+    auto file { icon->get_file() };
+    if( !file ) return {};
 
-    return Gdk::Pixbuf::create_from_file( path );
+    try
+    {
+        auto stream { file->read() }; // open Gio::InputStream from resource or file
+        return Gdk::Pixbuf::create_from_stream( stream );
+    }
+    catch( const Glib::Error& ex )
+    {
+        print_error( "Failed to load icon pixbuf: ", ex.what() );
+        return {};
+    }
 }
 
 } // end of name space
