@@ -944,7 +944,9 @@ struct CipherBuffers
 };
 
 // DROP POSITIONS ==================================================================================
-enum class DropPosition { NONE, BEFORE, INTO, AFTER };
+enum class DropPosition { NONE, BEFORE, INTO, AFTER, AFTER_ABSOLUTE };
+// AFTER can be regarded as INTO under certain circumstances
+// but AFTER_ABSOLUTE cannot
 
 // ENTRY WIDGET WITH SELF-HANDLED CLEAR ICON =======================================================
 class EntryClear : public Gtk::Entry
@@ -1114,7 +1116,8 @@ void                scroll_to_selected_LB_row( Gtk::ListBox* LB );
 void                select_LB_item_prev( Gtk::ListBox* );
 void                select_LB_item_next( Gtk::ListBox* );
 
-R2Pixbuf            lookup_default_icon_pixbuf( const Ustring& name, int size );
+R2Pixbuf            lookup_theme_icon_pixbuf( const Glib::RefPtr< Gtk::IconTheme >&,
+                                              const Ustring& name, int size );
 
 inline R2Icon
 lookup_default_icon( const Ustring& name, int size )
