@@ -36,11 +36,11 @@
 using namespace LIFEO;
 
 // STATIC MEMBERS
-const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "3.0.3"
+const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "3.0.4"
 #if LIFEOGRAPH_DEBUG_BUILD || defined( LIFEOGRAPH_BETA_STAGE )
         "\n" BUILD_TIMESTAMP
 #endif
-        "\n\"Madleen\"";
+        "\n\"Anas Al-Sharif\"";
 
 
 Lifeograph*                     Lifeograph::p;
@@ -181,6 +181,8 @@ button.dlg-msg { border-radius: 0px; }
 flowboxchild.spell-suggestion { color: #222222; background: #ff9999; border-radius: 5px; }
 
 .lifeo-map-label { color: #663333; background: #FFFFFFaa; }
+
+treeexpander#parent_of_selected_hidden { background: #999999; }
 )" );
 // maybe later: listview.entry-list row:selected { color: #330000; background: #d0aaaa; }
 // treeexpander indent padding is deue to a Gtk weirdness/bug
