@@ -49,7 +49,7 @@ Settings::read()
     {
         PRINT_DEBUG( "Configuration file does not exist, maiden voyage!" );
         Lifeograph::settings.rtflag_force_welcome = true;
-        recentfiles.insert( Lifeograph::EXAMPLEDIARYPATH );
+        recentfiles.insert( Glib::filename_to_uri( Lifeograph::EXAMPLEDIARYPATH ) );
 
         return false;
     }
@@ -96,8 +96,8 @@ Settings::read()
                     if( diary_extension[ 0 ] != '.' )
                         diary_extension.insert( 0, "." );
                     break;
-                // TODO: position & size settings may go to the diary
-                // TODO: check if these are within screen boundaries
+                // TODO: 3.2: position & size settings may go to the diary
+                // TODO: 3.2: check if these are within screen boundaries
                 case 'H':
                     height = std::stoi( line.substr( 2 ) );
                     break;
