@@ -55,7 +55,7 @@ class UIDiary
         void                    enable_editing2();
         void                    handle_logout();
 
-        void                    update_entry_list( const Entry* = nullptr );
+        void                    update_entry_list( /*const Entry* = nullptr*/ );
         //void                    update_entry_list_style();
 
         void                    update_all_entries_filter_status();
