@@ -399,7 +399,8 @@ WidgetChart::update_child_widgets_per_data()
 
     m_CB_col_filter->append( std::to_string( ChartData::COLUMN_NONE ),
                              STR::compose( "<", _( "None" ), ">" ) );
-    // TODO: splitting functionality for v3.1: m_CB_col_filter_v->append( STR::compose( "<", _( "Split" ), ">" ) );
+    // TODO: 3.1: splitting functionality:
+    // m_CB_col_filter_v->append( STR::compose( "<", _( "Split" ), ">" ) );
 
     // COLUMN VALUES
     for( const auto col : m_data.m_td->m_columns )
@@ -534,7 +535,7 @@ WidgetChart::on_motion_notify_event( double x, double y )
     else if( hovered_step != m_hovered_step )
     {
         m_hovered_step = hovered_step;
-        refresh();  // TODO: limit to tooltip area only
+        refresh();  // TODO: 3.1: limit to tooltip area only
     }
 
     m_F_widget_hovered = true;
