@@ -159,7 +159,7 @@ WidgetEntryList::handle_bind_row( const Glib::RefPtr< Gtk::ListItem >& list_item
                 m_drop_position = DropPosition::NONE;
                 queue_draw();
             } );
-    expander->add_controller( drag_source );
+    expander->get_parent()->add_controller( drag_source );
 
     auto drop_target { Gtk::DropTarget::create( G_TYPE_INVALID,
                                                 Gdk::DragAction::COPY|Gdk::DragAction::MOVE ) };
@@ -176,7 +176,7 @@ WidgetEntryList::handle_bind_row( const Glib::RefPtr< Gtk::ListItem >& list_item
             sigc::bind( sigc::mem_fun( *this, &WidgetEntryList::handle_drop ),
                         gentry->m_p2entry ),
             false );
-    expander->add_controller( drop_target );
+    expander->get_parent()->add_controller( drop_target );
 }
 void
 WidgetEntryList::handle_unbind_row( const Glib::RefPtr< Gtk::ListItem >& list_item )
@@ -187,9 +187,9 @@ WidgetEntryList::handle_unbind_row( const Glib::RefPtr< Gtk::ListItem >& list_it
 
     if( gentry )
     {
+        PRINT_DEBUG( "handle_UNbind:", gentry->m_p2entry->get_name() );
         gentry->m_connection_expand.disconnect();
         m_map_rows.erase( gentry->m_p2entry->get_id() );
-        PRINT_DEBUG( "handle_UNbind:", gentry->m_p2entry->get_name() );
     }
 }
 
@@ -212,6 +212,7 @@ WidgetEntryList::clear_and_disable()
 {
     m_F_editable = false;
     set_model( Gtk::SingleSelection::create() );
+    m_p2expander_last = nullptr;
 }
 
 void
@@ -220,6 +221,7 @@ WidgetEntryList::populate()
     Lifeograph::START_INTERNAL_OPERATIONS();
 
     clear_cut_entries(); // reset the cut entries at updates
+    m_p2expander_last = nullptr;
 
     // create the root model:
     auto root = create_model();
@@ -254,18 +256,8 @@ WidgetEntryList::populate()
         }
     }
 
-    // the following is the standard way but does not fire when the active entry...
-    // ...is a child of a collapsed parent and the parent is selected:
-    // m_selection_model->signal_selection_changed().connect(
-    //         sigc::mem_fun( *this, &WidgetEntryList::handle_selection_changed
-    //         ) );
-
-    auto gesture_click { Gtk::GestureClick::create() };
-    gesture_click->set_button( 1 );
-    gesture_click->signal_released().connect(
-                [ this ]( int, double, double ) { handle_selection_changed(); } );
-
-    add_controller( gesture_click );
+    m_selection_model->signal_selection_changed().connect(
+            sigc::mem_fun( *this, &WidgetEntryList::handle_selection_changed ) );
 
     set_model( m_selection_model );
 
@@ -273,24 +265,42 @@ WidgetEntryList::populate()
 }
 
 void
-WidgetEntryList::select( Entry* p2entry )
+WidgetEntryList::select( Entry* p2entry, const Entry* p2entry_exposed )
 {
     m_selected_entries.clear();
+    get_model()->unselect_all();
+    if( m_p2expander_last )
+    {
+        m_p2expander_last->unset_name();
+        m_p2expander_last = nullptr;
+    }
 
     Lifeograph::START_INTERNAL_OPERATIONS();
 
     if( p2entry )
     {
-        p2entry = p2entry->get_first_exposed_upwards();
-        const auto order { get_entry_order( p2entry ) };
-        if( order >= 0 )
+        if( !p2entry_exposed || p2entry_exposed == p2entry )
         {
-            get_model()->select_item( order, true );
-            m_selected_entries.insert( p2entry );
+            const auto order { get_entry_order( p2entry_exposed ? p2entry_exposed : p2entry ) };
+            if( order >= 0 )
+                get_model()->select_item( order, false );
         }
+        else
+        {
+            auto row { get_entry_row( p2entry_exposed ) };
+            if( row )
+            {
+                auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
+                if( gentry )
+                {
+                    m_p2expander_last =
+                        dynamic_cast< Gtk::TreeExpander* >( gentry->m_Bx->get_parent() );
+                    m_p2expander_last->set_name( "parent_of_selected_hidden" );
+                }
+            }
+        }
+        m_selected_entries.insert( p2entry );
     }
-    else
-        get_model()->unselect_all();
 
     Lifeograph::FINISH_INTERNAL_OPERATIONS();
 }
@@ -325,13 +335,16 @@ WidgetEntryList::present_entry_hard( const Entry* p2entry )
     if( F_expasion_done )
         populate();
 
-    scroll_to_and_select_entry( p2entry );
+    scroll_to_entry( p2entry );
+    select( const_cast< Entry* >( p2entry ) );
 }
 
 void
 WidgetEntryList::present_entry( const Entry* p2entry )
 {
-    scroll_to_and_select_entry( p2entry->get_first_exposed_upwards() );
+    auto p2entry_exposed { p2entry->get_first_exposed_upwards() };
+    scroll_to_entry( p2entry_exposed );
+    select( const_cast< Entry* >( p2entry ), p2entry_exposed );
 }
 
 void
@@ -416,7 +429,7 @@ WidgetEntryList::handle_key_press( guint keyval, guint, Gdk::ModifierType state
                 m_drop_position = DropPosition::INTO;
                 break;
             case int( Gdk::ModifierType::CONTROL_MASK ):
-                m_drop_position = DropPosition::AFTER;
+                m_drop_position = DropPosition::AFTER_ABSOLUTE;
                 break;
             case HELPERS::CTRL_SHIFT_MASK:
                 m_drop_position = DropPosition::BEFORE;
@@ -525,22 +538,19 @@ WidgetEntryList::handle_drop_motion( double x, double y,
     auto pt       { expander->compute_point( *this, Gdk::Graphene::Point( x, 0.0 ) ) };
     auto pt_2     { expander->compute_point( *this, Gdk::Graphene::Point( 0.0, 0.0 ) ) };
     auto dp_new   { DropPosition::NONE };
-    auto formats  { drop_target->get_formats() };
-    auto action   { Gdk::DragAction::COPY };
+    auto action   { m_id_dragged_entry == DEID_UNSET ? Gdk::DragAction::COPY
+                                                     : Gdk::DragAction::MOVE };
 
     // disable dropping onto itself:
     if( m_id_dragged_entry == target_entry->get_id() )
     {
-        PRINT_DEBUG( "contains entry");
-        action = Gdk::DragAction::MOVE;
-        return Gdk::DragAction( 0 );
+        PRINT_DEBUG( "drop target is the same as the source");
+        action = Gdk::DragAction( 0 );
     }
     else if( m_id_dragged_entry == DEID_MULTIPLE )
     {
-        PRINT_DEBUG( "contains multiple entries");
-        action = Gdk::DragAction::MOVE;
         if( m_selected_entries.find( target_entry ) != m_selected_entries.end() )
-            return Gdk::DragAction( 0 );
+            action = Gdk::DragAction( 0 );
     }
 
     if( m_line_height < 1 )
@@ -549,7 +559,11 @@ WidgetEntryList::handle_drop_motion( double x, double y,
     m_drop_coord_x = pt_2->get_x();
 
     // EVALUATE THE HOVERED ELEMENT
-    if     ( pt->get_x() < OFFSET_DROP_INTO || m_id_dragged_entry == DEID_UNSET )
+    if( action == Gdk::DragAction( 0 ) )
+    {
+        dp_new = DropPosition::NONE;
+    }
+    else if( pt->get_x() < OFFSET_DROP_INTO || m_id_dragged_entry == DEID_UNSET )
     {
         dp_new = DropPosition::INTO;
         m_drop_coord_y = pt->get_y();
@@ -628,7 +642,7 @@ WidgetEntryList::handle_drop( const Glib::ValueBase& value, double x, double y,
                                                        VT::ETS::INHERIT::I ) };
             // actual position is set in the next step:
             p2entry_rcvn->get_diary()->move_entry( entry_new, p2entry_rcvn, m_drop_position );
-            AppWindow::p->UI_diary->update_entry_list( p2entry_rcvn );
+            AppWindow::p->UI_diary->update_entry_list();
         }
     }
     else if( G_VALUE_HOLDS( value.gobj(), Theme::GValue::value_type() ) )
@@ -649,7 +663,7 @@ WidgetEntryList::handle_drop( const Glib::ValueBase& value, double x, double y,
         p2entry_rcvn->get_diary()->move_entry( p2entry_drpd, p2entry_rcvn, m_drop_position );
 
         // AppWindow::p->UI_entry->refresh_extra_info();
-        AppWindow::p->UI_diary->update_entry_list( p2entry_drpd );
+        AppWindow::p->UI_diary->update_entry_list();
     }
     else if( G_VALUE_HOLDS( value.gobj(), LIFEO::EntrySelection::GValue::value_type() ) )
     {
@@ -662,7 +676,7 @@ WidgetEntryList::handle_drop( const Glib::ValueBase& value, double x, double y,
                                                  m_drop_position );
 
         // AppWindow::p->UI_entry->refresh_extra_info();
-        AppWindow::p->UI_diary->update_entry_list( p2entry_rcvn );
+        AppWindow::p->UI_diary->update_entry_list();
     }
     else
     {
@@ -675,7 +689,7 @@ WidgetEntryList::handle_drop( const Glib::ValueBase& value, double x, double y,
 }
 
 void
-WidgetEntryList::handle_selection_changed( /*guint pos, guint n_items*/ )
+WidgetEntryList::handle_selection_changed( guint pos, guint n_items )
 {
     // NOTE: we did not use the pos & n_items as it turned out to be quite hard
     // to keep an uptodate list of selected items
@@ -755,13 +769,23 @@ WidgetEntryList::handle_expand_changed( const Glib::RefPtr< Gtk::TreeListRow >&
     if( Lifeograph::is_internal_operations_ongoing() ) return;
 
     auto gentry { std::dynamic_pointer_cast< GObjectEntry >( row->get_item() ) };
-    if( !gentry ) return;
-    gentry->m_p2entry->set_expanded( row->get_expanded() );
-    if( !row->get_expanded() )
+    if( gentry )
     {
+        gentry->m_p2entry->set_expanded( row->get_expanded() );
+        if( m_p2expander_last )
+        {
+            // clear it before it gors out of scope:
+            m_p2expander_last->unset_name();
+            m_p2expander_last = nullptr;
+        }
+
         if( AppWindow::p->UI_entry->get_cur_entry()->is_descendant_of( gentry->m_p2entry ) )
             Glib::signal_idle().connect_once(
-                    [ this ](){ select( AppWindow::p->UI_entry->get_cur_entry() ); } );
+                    [ this ]()
+                    {
+                        Entry* p2ec { AppWindow::p->UI_entry->get_cur_entry() };
+                        select( p2ec, p2ec->get_first_exposed_upwards() );
+                    } );
     }
 
     PRINT_DEBUG( "entry [", gentry->m_p2entry->get_name(),
