@@ -69,6 +69,7 @@ EntryPickerCompletion::EntryPickerCompletion( Gtk::Widget& parent )
     s_F_offer_new = false; // blocks infinite recursion
     m_WEP_new_under = Gtk::Builder::get_widget_derived< WidgetEntryPicker >( m_builder,
                                                                              "E_new_under" );
+    m_WEP_new_under->set_name( "noncustom" );
     B_add           = m_builder->get_widget< Gtk::Button >( "B_add" );
     B_add->signal_clicked().connect( std::bind( &EntryPickerCompletion::create_new_entry, this ) );
 }
@@ -153,7 +154,7 @@ EntryPickerCompletion::popup( const Gdk::Rectangle& rect, const Ustring& filter
 {
     update_list( filter );
 
-    if( !m_LB->get_first_child() ) // means: if empty TODO: is this still meaningful?
+    if( !m_LB->get_first_child() ) // means: if empty
         return;
 
     m_LB->select_row( * m_LB->get_row_at_index( 0 ) );
@@ -231,12 +232,7 @@ EntryPickerCompletion::handle_key( guint keyval, bool F_ctrl, bool F_shift )
         return false;
     else if( F_ctrl )
     {
-        if( keyval == GDK_KEY_Right && get_selected() ) // TODO: what is this doing?
-        {
-            update_list( get_selected()->get_name() );
-            return true;
-        }
-        else if( keyval == GDK_KEY_Return )
+        if( keyval == GDK_KEY_Return )
         {
             create_new_entry();
             return true;
@@ -262,6 +258,8 @@ EntryPickerCompletion::handle_key( guint keyval, bool F_ctrl, bool F_shift )
                     m_Sg_entry_activated.emit( e );
                     popdown();
                 }
+                else // i.e. create new entry is secected
+                    m_WEP_new_under->grab_focus();
                 return true;
             }
             case GDK_KEY_Escape:
@@ -459,7 +457,7 @@ WidgetEntryPicker::handle_entry_selected( LIFEO::Entry* entry )
 
 Gdk::DragAction
 WidgetEntryPicker::handle_drop_motion( double x, double y )
-// TODO: gtkmm4: this function is probably no longer needed
+// TODO: 3.1: gtkmm4: this function is probably no longer needed
 {
     // if( Lifeograph::get_dragged_elem() != nullptr &&
     //     Lifeograph::get_dragged_elem()->get_type() >= DiaryElement::ET_ENTRY )
