@@ -435,27 +435,33 @@ WidgetTable::on_resize( int w, int h )
     if( w != m_width || h != m_height )
     {
         resize( w, h );
-        m_row_h = 0.0; // to trigger updates during draw
+        update_line_c_vis();
+        update_height_vline();
+        update_scrollbar();
+        update_col_geom();
     }
 }
 
+void
+WidgetTable::on_realize()
+{
+    if( !m_layout )
+        m_layout = Pango::Layout::create( get_pango_context() );
+
+    calculate_row_h();
+    update_line_c_vis();
+    if( !update_scrollbar() )
+    {
+        update_height_vline();
+        update_col_geom();
+    }
+
+    Gtk::Widget::on_realize();
+}
+
 void
 WidgetTable::on_draw( const Cairo::RefPtr< Cairo::Context >& cr, int w, int h )
 {
-    if( !m_layout )
-        m_layout = Pango::Layout::create( cr );
-
-    if( m_row_h == 0.0 )
-    {
-        calculate_row_h();
-        update_line_c_vis();
-        if( !update_scrollbar() )
-        {
-            update_height_vline();
-            update_col_geom();
-        }
-    }
-
     Table::draw( cr );
 }
 
