@@ -470,13 +470,11 @@ TextviewDiary::toggle_collapse_all_subheaders()
 void
 TextviewDiary::set_theme( const Theme* theme )
 {
-    if( m_p2theme )
-        remove_css_class( m_p2theme->get_css_class_name() );
-
     // when theme == nullptr, it works in refresh mode:
     m_p2theme = theme ? theme : m_p2entry->get_theme();
 
-    add_css_class( m_p2theme->get_css_class_name() );
+    // set theme by changing the name:
+    set_name( m_p2theme->get_css_class_name() );
 
     m_tag_heading->property_foreground_rgba() = m_p2theme->color_heading;
     m_tag_subheading->property_foreground_rgba() = m_p2theme->color_subheading;
@@ -672,7 +670,7 @@ TextviewDiary::process_paragraph( Paragraph* para,
         }
 
         // INDENTATION
-        // TODO: v3.0: for empty paragraphs this breaks the indentation of the following paragraph
+        // TODO: 3.1: for empty paragraphs this breaks the indentation of the following paragraph
         switch( para->get_indent_level() )
         {
             case 1: m_r2buffer->apply_tag( m_tag_indent_1, it_bgn, it_end ); break;
@@ -917,7 +915,7 @@ TextviewDiary::copy_clipboard( bool F_cut )
     if( !get_clipboard()->set_content( content_provider_combined ) )
         print_error( "Copying to clipboard failed!" );
 
-    // TODO: implement rich text for external applications
+    // TODO: 3.2: implement rich text for external applications
 
     if( F_cut )
         m_r2buffer->erase( it_bgn, it_end );
@@ -1141,7 +1139,7 @@ TextviewDiary::process_link_uri( const Paragraph* para_hovered, int offset )
             };
             break;
         default:
-            m_p2hflink_hovered = nullptr;
+            set_hovered_link( nullptr );
             break;
     }
 }
@@ -1410,6 +1408,9 @@ TextviewDiary::snapshot_vfunc( const Glib::RefPtr< Gtk::Snapshot >& snapshot )
         int             y_hover_top{ 0 }, y_quot_top{ 0 }, y_quot_bottom{ 0 }, h_line{ 0 };
         Paragraph*      p, * p_last{ nullptr };
         auto&&          textlayout{ Pango::Layout::create( cr ) };
+        auto&&          textlayout_header{ Pango::Layout::create( cr ) };
+        Pango::AttrList attrlist;
+        auto&&          attscale { Pango::Attribute::create_attr_scale( 1.4 ) };
 
         auto draw_icon = [ & ]( R2Pixbuf& buf )
         {
@@ -1481,13 +1482,14 @@ TextviewDiary::snapshot_vfunc( const Glib::RefPtr< Gtk::Snapshot >& snapshot )
         auto draw_number = [ & ]()
         {
             int textw, texth;
+            auto& tl { p->get_heading_level() == VT::PS_SUBHDR ? textlayout_header : textlayout };
             Gdk::Cairo::set_source_rgba( cr, m_p2theme->color_subsubheading );
-            textlayout->set_text( p->get_list_order_str() );
-            textlayout->get_pixel_size( textw, texth );
+            tl->set_text( p->get_list_order_str() );
+            tl->get_pixel_size( textw, texth );
             cr->move_to( PAGE_MARGIN + EXPANDER_WIDTH + 27 +
                          p->get_indent_level() * INDENT_WIDTH - textw,
                          y_para );
-            textlayout->show_in_cairo_context( cr );
+            tl->show_in_cairo_context( cr );
         };
         auto draw_quotation_end = [ & ]()
         {
@@ -1546,6 +1548,9 @@ TextviewDiary::snapshot_vfunc( const Glib::RefPtr< Gtk::Snapshot >& snapshot )
         };
 
         textlayout->set_font_description( m_p2theme->font );
+        textlayout_header->set_font_description( m_p2theme->font );
+        attrlist.insert( attscale );
+        textlayout_header->set_attributes( attrlist );
 
         // PARAGRAPHS
         for( p = para_bgn; p; p = p->get_next_visible() )
