@@ -116,7 +116,8 @@ TextviewDiarySearch::set_text_from_matches( Diary::SetMatches* matches )
 
                 if     ( last_entry_id != format->ref_id ) // separate entries more strongly
                     type = VT::PS_SEPRTR_E;
-                else if( last_remote_para != para->m_p2prev )
+                // unless consequtive para or another match in the sam para, add separator:
+                else if( last_remote_para != para->m_p2prev && last_remote_para != para )
                     type = VT::PS_SEPRTR_P;
 
                 if( type != 0 )
