@@ -297,7 +297,7 @@ TextviewDiaryTheme::handle_file_result( Glib::RefPtr< Gio::AsyncResult >& result
 void
 TextviewDiaryTheme::handle_link_theme()
 {
-    Theme* theme{ const_cast< Theme* >( get_theme() ) };
+    Theme* theme { const_cast< Theme* >( m_p2theme ) };
 
     switch( m_p2hflink_hovered->uri[ 0 ] )
     {
@@ -321,6 +321,8 @@ TextviewDiaryTheme::handle_link_theme()
             break;
         case 'i':
             theme->image_bg.clear();
+            set_theme( m_p2theme );
+            handle_theme_edited();
             break;
         case 'F':
             launch_font_dialog( &theme->font );
